==> 4.7.4.tar.gz: terraform-provider-decort/wiki/4.7.1/07.01.23-Resource_decort_image_from_blank_compute.md <==
Функция доступна в провайдере версии 4.6.0 и выше.

_Resource_ функция **decort_image_from_blank_compute** служит для управления образом, созданным из пустого компьюта.

## Аргументы

_Resource_ функция **decort_image_from_blank_compute** для создания образа принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| compute_id           | int   | :heavy_check_mark: | ID ВМ, которая была создана как blank |            
| name | string | :heavy_check_mark: | Имя образа<br/>При изменении - изменяет название образа |
| boot_type | string | :heavy_check_mark: | Тип загрузки образа,<br/>возможные варианты: "bios" или "uefi" |
| type | string | :heavy_check_mark: | Тип образа,<br />возможные варианты - "linux", "windows" |
| account_id | int | :x: | ID аккаунта владельца образа |
| username | string | :x: | Имя пользователя |
| password | string | :x: | Пароль пользователя |
| sep_id | int | :x: | ID storage endpoint |
| pool_name | string | :x: | Пул для создания образа |
| hot_resize | bool | :x: | Использует ли машина горячее изменение размера образа |
| async_mode | bool | :x: | Синхронное создание образа, используется при создании. Значение по умолчанию: false. |

## Возвращаемые значения

В случае успешного выполнения _resource_ функция **decort_image_from_blank_compute** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| account_id | int | accountId привязки образа |
| ckey | string | Ckey |
| acl | string | Информация об аккаунте |
| architecture | string | Архитектура образа, возможен вариант X86_64 |
| boot_type | string | Тип запуска ОС - bios или uefi |
| bootable | bool | Является ли образ загрузочным |
| compute_ci_id | int | ID вычислительного ресурса |
| cd_presented_to | string | Подключение образа |
| deleted_time | int | Время удаления ресурса |
| desc | string | Описание образа |
| drivers | []string | Список используемых драйверов |
| enabled | bool | Доступность образа |
| gid | int | ID платформы, где образ будет создан |
| guid | int | Внутренний id образа, совпадает с image_id |
| history | object{id: int, guid: int, timestamp: int} | История обновлений образа |
| hot_resize | bool | Использует ли машина горячее изменение размера образа |
| type | string | Тип образа: linux, windows или другой |
| last_modified | int | Дата последнего изменения |
| link_to | int | Привязка к образу, используется в виртуальных образах |
| milestones | int | Вехи |
| image_name | string | Название образа |
| network_interface_naming | string | Название сетевого интерфейса |
| pool_name | string | Пул, в котором был создан образ |
| provider_name | string | Наименование провайдера |
| purge_attempts | int | Попытки |
| present_to | []int | Список ID ресурсов для который предоставлен образ |
| res_id | string | ID ресурса |
| rescuecd | bool | cd или нет |
| sep_id | int | storage endpoint provider ID |
| shared_with | []int | Список ресурсов, имеющих доступ к образу |
| size | int | Размер образа |
| status | string | Статус образа |
| tech_status | string | Технический статус |
| unc_path | string | unc path |
| version | string | Версия |

## Пример использования

Пример вызова _resource_ функции **decort_image_from_blank_compute**:

```terraform
resource "decort_image_from_blank_compute" "img" {
  #id виртуальной машины, созданной как blank
  #обязательный параметр
  #используется для создания образа
  #тип - целое число
  compute_id = 1234

  #наименование образа
  #обязательный параметр
  #используется для создания и обновления образа
  #тип - строка
  name = "image_name"

  #тип загрузчика (bios/uefi)
  #обязательный параметр
  #используется для создания образа
  #тип - строка
  boot_type = "bios"

  #тип образа (linux, windows и др.)
  #обязательный параметр
  #используется для создания образа
  #тип - строка
  type = "linux"

  #юзернейм для образа
  #опциональный параметр
  #используется для создания образа
  #тип - строка
  #username = "userx"

  #пароль для образа
  #опциональный параметр
  #используется для создания образа
  #тип - строка
  #password = "passx"

  #id аккаунта
  #опциональный параметр
  #используется для создания образа
  #тип - целое число
  #account_id = 138

  #storage endpoint provider ID
  #опциональный параметр
  #используется для создания образа
  #тип - целое число
  #sep_id = 1

  #pool для образа
  #опциональный параметр
  #используется для создания образа
  #тип - строка
  #pool_name = "pool"

  #поддержка hot resize
  #опциональный параметр
  #используется для создания образа
  #тип - булев
  #hot_resize = true

  #флаг для создания образа в асинхронном режиме
  #опциональный параметр
  #дефолтное значение - false
  #тип - булев
  #async_mode = true

}
```

После успешного завершения такого вызова **decort_image_from_blank_compute** в переменной `decort_image_from_blank_compute.img` будут сохранены возвращаемые значения.

==> 4.9.0.tar.gz: terraform-provider-decort/wiki/4.6.0/07.01.23-Resource_decort_image_from_blank_compute.md <==
Функция доступна в провайдере версии 4.6.0 и выше.

_Resource_ функция **decort_image_from_blank_compute** служит для управления образом, созданным из пустого компьюта.

## Аргументы

_Resource_ функция **decort_image_from_blank_compute** для создания образа принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| compute_id           | int   | :heavy_check_mark: | ID ВМ, которая была создана как blank |            
| name | string | :heavy_check_mark: | Имя образа<br/>При изменении - изменяет название образа |
| boot_type | string | :heavy_check_mark: | Тип загрузки образа,<br/>возможные варианты: "bios" или "uefi" |
| type | string | :heavy_check_mark: | Тип образа,<br />возможные варианты - "linux", "windows" |
| account_id | int | :x: | ID аккаунта владельца образа |
| username | string | :x: | Имя пользователя |
| password | string | :x: | Пароль пользователя |
| sep_id | int | :x: | ID storage endpoint |
| pool_name | string | :x: | Пул для создания образа |
| hot_resize | bool | :x: | Использует ли машина горячее изменение размера образа |
| async_mode | bool | :x: | Синхронное создание образа, используется при создании. Значение по умолчанию: false. |
| permanently | bool | :x: | Мгновенное удаление<br/>можно использовать перед удалением |

## Возвращаемые значения

В случае успешного выполнения _resource_ функция **decort_image_from_blank_compute** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| account_id | int | accountId привязки образа |
| ckey | string | Ckey |
| acl | string | Информация об аккаунте |
| architecture | string | Архитектура образа, возможен вариант X86_64 или PPC64_LE |
| boot_type | string | Тип запуска ОС - bios или uefi |
| bootable | bool | Является ли образ загрузочным |
| compute_ci_id | int | ID вычислительного ресурса |
| cd_presented_to | string | Подключение образа |
| deleted_time | int | Время удаления ресурса |
| desc | string | Описание образа |
| drivers | []string | Список используемых драйверов |
| enabled | bool | Доступность образа |
| gid | int | ID платформы, где образ будет создан |
| guid | int | Внутренний id образа, совпадает с image_id |
| history | object{id: int, guid: int, timestamp: int} | История обновлений образа |
| hot_resize | bool | Использует ли машина горячее изменение размера образа |
| type | string | Тип образа: linux, windows или другой |
| last_modified | int | Дата последнего изменения |
| link_to | int | Привязка к образу, используется в виртуальных образах |
| milestones | int | Вехи |
| image_name | string | Название образа |
| network_interface_naming | string | Название сетевого интерфейса |
| permanently | bool | Удаление образа: мгновенное или нет |
| pool_name | string | Пул, в котором был создан образ |
| provider_name | string | Наименование провайдера |
| purge_attempts | int | Попытки |
| present_to | []int | Список ID ресурсов для который предоставлен образ |
| res_id | string | ID ресурса |
| rescuecd | bool | cd или нет |
| sep_id | int | storage endpoint provider ID |
| shared_with | []int | Список ресурсов, имеющих доступ к образу |
| size | int | Размер образа |
| status | string | Статус образа |
| tech_status | string | Технический статус |
| unc_path | string | unc path |
| version | string | Версия |

## Пример использования

Пример вызова _resource_ функции **decort_image_from_blank_compute**:

```terraform
resource "decort_image_from_blank_compute" "img" {
  #id виртуальной машины, созданной как blank
  #обязательный параметр
  #используется для создания образа
  #тип - целое число
  compute_id = 1234

  #наименование образа
  #обязательный параметр
  #используется для создания и обновления образа
  #тип - строка
  name = "image_name"

  #тип загрузчика (bios/uefi)
  #обязательный параметр
  #используется для создания образа
  #тип - строка
  boot_type = "bios"

  #тип образа (linux, windows и др.)
  #обязательный параметр
  #используется для создания образа
  #тип - строка
  type = "linux"

  #юзернейм для образа
  #опциональный параметр
  #используется для создания образа
  #тип - строка
  #username = "userx"

  #пароль для образа
  #опциональный параметр
  #используется для создания образа
  #тип - строка
  #password = "passx"

  #id аккаунта
  #опциональный параметр
  #используется для создания образа
  #тип - целое число
  #account_id = 138

  #storage endpoint provider ID
  #опциональный параметр
  #используется для создания образа
  #тип - целое число
  #sep_id = 1

  #pool для образа
  #опциональный параметр
  #используется для создания образа
  #тип - строка
  #pool_name = "pool"

  #поддержка hot resize
  #опциональный параметр
  #используется для создания образа
  #тип - булев
  #hot_resize = true

  #флаг для создания образа в асинхронном режиме
  #опциональный параметр
  #дефолтное значение - false
  #тип - булев
  #async_mode = true

  #флаг окончательного удаления
  #опциональный параметр
  #тип - булев
  #permanently = true
  
}
```

После успешного завершения такого вызова **decort_image_from_blank_compute** в переменной `decort_image_from_blank_compute.img` будут сохранены возвращаемые значения.
